Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/diy/__init__.py | 3 | 0 | 0 | 100%
src/diy/container.py | 58 | 9 | 0 | 84%
src/diy/errors.py | 38 | 13 | 0 | 66%
src/diy/specification.py | 71 | 28 | 0 | 61%
tests/container_test.py | 64 | 1 | 0 | 98%
tests/specification_test.py | 12 | 2 | 0 | 83%
Total | 246 | 53 | 0 | 78%

No items found using the specified filter.